EXPORTS
	??1CBioTestUtils@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CBioTestUtils::~CBioTestUtils(void)
	?CreateBIOEntryFromFileL@CBioTestUtils@@QAEJABVTDesC16@@W4TBIOMessageType@@@Z @ 2 NONAME ; public: long __thiscall CBioTestUtils::CreateBIOEntryFromFileL(class TDesC16 const &,enum TBIOMessageType)
	?CreateBIOEntryL@CBioTestUtils@@QAEJAAVTDesC16@@W4TBIOMessageType@@@Z @ 3 NONAME ; public: long __thiscall CBioTestUtils::CreateBIOEntryL(class TDesC16 &,enum TBIOMessageType)
	?CreateBioServerMtmRegL@CBioTestUtils@@QAEXXZ @ 4 NONAME ; public: void __thiscall CBioTestUtils::CreateBioServerMtmRegL(void)
	?CreateParserL@CBioTestUtils@@QAEPAVCBaseScriptParser@@J@Z @ 5 NONAME ; public: class CBaseScriptParser * __thiscall CBioTestUtils::CreateParserL(long)
	?CreateParserTypeL@CBioTestUtils@@QAEPAVCBaseScriptParser@@J@Z @ 6 NONAME ; public: class CBaseScriptParser * __thiscall CBioTestUtils::CreateParserTypeL(long)
	?EmptyInboxMessagesL@CBioTestUtils@@QAEXXZ @ 7 NONAME ; public: void __thiscall CBioTestUtils::EmptyInboxMessagesL(void)
	?GenerateMessagesL@CBioTestUtils@@QAEPAVCMsvEntrySelection@@ABVTDesC16@@H@Z @ 8 NONAME ; public: class CMsvEntrySelection * __thiscall CBioTestUtils::GenerateMessagesL(class TDesC16 const &,int)
	?GenerateMessagesL@CBioTestUtils@@QAEPAVCMsvEntrySelection@@XZ @ 9 NONAME ; public: class CMsvEntrySelection * __thiscall CBioTestUtils::GenerateMessagesL(void)
	?LogCurrentMessageTypeL@CBioTestUtils@@QAEXJ@Z @ 10 NONAME ; public: void __thiscall CBioTestUtils::LogCurrentMessageType(long)
	?LogExtractedFieldsL@CBioTestUtils@@QAEXJ@Z @ 11 NONAME ; public: void __thiscall CBioTestUtils::LogExtractedFieldsL(long)
	?MessageBodyL@CBioTestUtils@@QAE?AVTPtrC16@@J@Z @ 12 NONAME ; public: class TPtrC16  __thiscall CBioTestUtils::MessageBodyL(long)
	?NewL@CBioTestUtils@@SAPAV1@AAVRTest@@@Z @ 13 NONAME ; public: static class CBioTestUtils * __cdecl CBioTestUtils::NewL(class RTest &)
	?NewL@CBioTestUtils@@SAPAV1@AAVRTest@@H@Z @ 14 NONAME ; public: static class CBioTestUtils * __cdecl CBioTestUtils::NewL(class RTest &,int)
	?NewLC@CBioTestUtils@@SAPAV1@AAVRTest@@@Z @ 15 NONAME ; public: static class CBioTestUtils * __cdecl CBioTestUtils::NewLC(class RTest &)
	?NewLC@CBioTestUtils@@SAPAV1@AAVRTest@@H@Z @ 16 NONAME ; public: static class CBioTestUtils * __cdecl CBioTestUtils::NewLC(class RTest &,int)
	?ParsedFieldArray@CBioTestUtils@@QAEAAV?$CArrayPtrSeg@VCParsedField@@@@XZ @ 17 NONAME ; public: class CArrayPtrSeg<class CParsedField> & __thiscall CBioTestUtils::ParsedFieldArray(void)
	?Reset@CBioTestUtils@@UAEXXZ @ 18 NONAME ; public: virtual void __thiscall CBioTestUtils::Reset(void)
	?SetBIOServiceIdL@CBioTestUtils@@QAEJXZ @ 19 NONAME ; public: long __thiscall CBioTestUtils::SetBIOServiceIdL(void)
	?SetSessionPath@CBioTestUtils@@QAEXABVTDesC16@@@Z @ 20 NONAME ; public: void __thiscall CBioTestUtils::SetSessionPath(class TDesC16 const &)
	?DoAppendVariantName@CBioTestUtils@@SAXAAVTDes16@@@Z @ 21 NONAME ; public: static void __cdecl CBioTestUtils::DoAppendVariantName(class TDes16 &)
	?SetMessageType@CBioTestUtils@@QAE?AW4TBIOMessageType@@ABVTDesC16@@@Z @ 22 NONAME ; public: enum TBIOMessageType  __thiscall CBioTestUtils::SetMessageType(class TDesC16 const &)

